function [model] = runCrossVal(X, Y, subsets)

for s = 1:max(subsets) % s is current TEST subset
        
    % Get the training data
    Xtrain = X(subsets ~= s, :);
    Ytrain = Y(subsets ~= s);
    
    % Get the testing data
    Xtest = X(subsets == s, :);
    Ytest = Y(subsets == s, :);
    
    % Solve the least squares optimization to find weights
    w = (Xtrain' * Xtrain) \ (Xtrain' * Ytrain);
    
    % Generate predictions on training data
    YhatTrain = Xtrain*w;
    YhatTest = Xtest*w;
    
    % Compute the mean absolute error on training and test:
    
    % Note: here, the dot operator creates a new STRUCT, called model.
    % Structs are a lot like structs in C -- they have fields associated
    % with them, and they are most useful for grouping together related
    % variables. Here, we group together all results relating to the model
    % -- the parameters, and the performance -- into a convenient struct.
        
    % Note also that structs are really easy to use -- simply setting the
    % value to a field will create it. See DOC STRUCT for more information.
    
    model.trainMAE(s) = mean(abs(YhatTrain - Ytrain));
    model.testMAE(s) = mean(abs(YhatTest - Ytest));
        
end

model.w = w;